const system = require("../../../system");
var settings = require("../../../../config/settings");
const _ = require("lodash")
const md5 = require("MD5");

class TmqueryService {
    constructor() {
        this.channelApiUrl = "https://tm.plus.jdcloud.com";
        this.zcApiUrl = settings.reqZcApi();
        this.reqEsAddr = settings.reqEsAddr();
        this.execClient = system.getObject("util.execClient");
        this.execClientNew = system.getObject("util.execClientNew");
    }

    /**
     * 验证签名
     * @param {*} params 要验证的参数
     * @param {*} app_key 应用的校验key
     * @param {*} isEmptySign params key 对应值为空是否参与签名
     */
    createSign(params, app_key, isEmptySign) {
        if (!params) {
            return system.getResult(null, "请求参数为空");
        }
        var signArr = [];
        var keys = Object.keys(params).sort();
        if (keys.length == 0) {
            return system.getResult(null, "请求参数信息为空");
        }
        for (let k = 0; k < keys.length; k++) {
            const tKey = keys[k];
            if (tKey != "sign") {
                if (tKey != "token") {
                    if (tKey != "actionProcess") {
                        if (isEmptySign) {
                            signArr.push(tKey + "=" + params[tKey]);
                        } else {
                            if (params[tKey]) {
                                signArr.push(tKey + "=" + params[tKey]);
                            }
                        }
                    }
                }
            }
        }
        if (signArr.length == 0) {
            return system.getResult(null, "请求参数组装签名参数信息为空");
        }
        var resultSignStr = signArr.join("&") + "&key=" + app_key;
        var resultTmpSign = md5(resultSignStr).toUpperCase();
        return system.getResultSuccess(resultTmpSign);
    }

    async findTrademarkNameAccurate(queryobj, req) {//通过商标名来进行精准查询
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/findTrademarkNameAccurate";
        return await this.opReqResult(url, queryobj, req);
    }

    async findTrademarkNameIndex(queryobj, req) {//根据商标名称模糊查询,首次查询,
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/findTrademarkNameIndex";
        return await this.opReqResult(url, queryobj, req);
    }

    async findTrademarkName(queryobj, req) {//根据商标名称模糊查询
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/findTrademarkName";
        return await this.opReqResult(url, queryobj, req);
    }

    async findTrademarkzchAccurate(queryobj, req) {//通过商标号来进行精准查询
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/findTrademarkzchAccurate";
        return await this.opReqResult(url, queryobj, req);
    }

    async findTrademarkzcr(queryobj, req) {//通过注册人模糊查询
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/findTrademarkzcr";
        return await this.opReqResult(url, queryobj, req);
    }

    async imagequery(queryobj, req) {//图像检索
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/imagequery";
        return await this.opReqResult(url, queryobj, req);
    }

    async findImageSearch(queryobj, req) { //图像检索查询，
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/findImageSearch";
        return await this.opReqResult(url, queryobj, req);
    }

    async tradeMarkDetail(queryobj, req) {//商标详情
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/tradeMarkDetail";
        return await this.opReqResult(url, queryobj, req);
    }

    async sbzuixinsearch(queryobj, req) {
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/sbzuixinsearch";
        return await this.opReqResult(url, queryobj, req);
    }

    async noticequeryTMZCSQ(queryobj, req) {
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/noticequeryTMZCSQ";
        return await this.opReqResult(url, queryobj, req);
    }

    async noticequery(queryobj, req) {
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/noticequery";
        return await this.opReqResult(url, queryobj, req);
    }

    async noticezcggsearch(queryobj, req) {
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/noticezcggsearch";
        return await this.opReqResult(url, queryobj, req);
    }

    async noticesearch(queryobj, req) {
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/noticesearch";
        return await this.opReqResult(url, queryobj, req);
    }

    async getCompanyInfoNoUser(queryobj, req) {
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/getCompanyInfoNoUser";
        return await this.opReqResult(url, queryobj, req);
    }

    async getNclDetail(queryobj, req) {
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/getNclDetail";
        return await this.opReqResult(url, queryobj, req);
    }

    async gettwoNcl(queryobj, req) {
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/gettwoNcl";
        return await this.opReqResult(url, queryobj, req);
    }

    async nclFuwuSearch(queryobj, req) {
        var url = this.zcApiUrl + "api/trademark/tmqueryApi/nclFuwuSearch";
        return await this.opReqResult(url, queryobj, req);
    }

    async opReqResult(reqUrl, queryobj, req) {
        var rtn = await this.execClient.execPushDataPost(queryobj, reqUrl, req.headers["token"], req.headers["request-id"]);
        var data = JSON.parse(rtn.stdout);
        return data;
    }

    async pushJdPayOrder(queryobj, req) {
        /**
         * 请求es 拿出数据，组装
         */
        let failOrders = [];
        var self = this;
        try {
            const data = await this.execClient.execPostTimeOut({
                "query": {
                    "bool": {
                        "must": [
                            {
                                "query_string": {
                                    "default_field": "optitle",
                                    "query": "\"###处理京东推送的订单信息参数\""
                                }
                            },
                            {
                                "query_string":{
                                    "default_field":"content",
                                    "query":"\"FW_GOODS-582206-1\""
                                }
                            }
                        ]
                    }
                },
                "from": queryobj.from || 0,
                "size": queryobj.size || 2000,
                "sort": [
                    {
                        "created_at": "desc"
                    }
                ]
            }, `${this.reqEsAddr}bigdata_zc_op_log/_search`, 30000);
            let result = data.stdout;
            result = JSON.parse(result);
            result = result.hits.hits;
            result = _.uniqBy(result.map(item => {
                return JSON.parse(item._source.content.replace(/pushData参数=/g, ""))
            }).filter(item => {
                return item.skuId
            }), "orderNumber").filter(item => {
                const signResult = this.createSign(item, "F6FBD101C7571ADE231670F080653874", true);
                if (signResult.status != 0 || signResult.data != item.token.toUpperCase()) {
                    failOrders.push({
                        errMsg: "签名失败",
                        param: item
                    });
                    return false
                } else {
                    return true;
                }
            });
            var tokenInfo = await this.getToken();
            if (tokenInfo.status != 0) {
                return tokenInfo;
            }
            this.execClientNew.execLogs("igirl-channel-pushJdPayOrder-去重后的数据集合", queryobj, "igirl-channel-pushJdPayOrder", result, null);
            let buildResult = [];
            for (let pushData of result) {
                //自助注册产品---用updateOrderPayStatus，否则为addOrderAndDelivery
                let param = {
                    actionProcess: pushData.actionProcess,
                    actionType: "",
                    actionBody: {
                        channelUserId: pushData.jdPin,
                        payStatus: "yfk",
                        channelItemCode: pushData.skuId,//------用此字段查询渠道产品是否存在
                        needNo: pushData.skuId + "_" + pushData.orderNumber,
                        needNoOrderNo: pushData.orderNumber,//---用此字段查找
                        buyerMoblie: pushData.mobile,
                        payCode: pushData.skuId,
                        email: pushData.email
                    },
                    isUser: "yes"
                };
                if (["FW_GOODS-582206-1", "FW_GOODS-582208-1", "FW_GOODS-582207-1"].indexOf(pushData.skuId) >= 0) {
                    param.actionType = pushData.skuId == "FW_GOODS-582206-1" ? "updateOrderPayStatusJd" : "addOrderAndDelivery";
                }//商标的产品订单
                else {
                    param.actionBody.channelItemCode = pushData.serviceCode;
                    param.actionType = "jdAddQifuOrder";
                }//工商产品订单

                let reqUrl = self.channelApiUrl + "/action/tmOrder/springBoard";
                let rtn = await self.execClient.execPushDataPost(param, reqUrl, tokenInfo.data.token, req.headers["request-id"], 10000);
                self.execClientNew.execLogs("igirl-channel-pushJdPayOrder-去重后的数据处理结果", param, "igirl-channel-pushJdPayOrder", rtn, null);
                if (!rtn || !rtn.stdout) {
                    failOrders.push(
                        {
                            orderNumber: item.orderNumber,
                            errMsg: "this.execClient.execPushDataPost无返回"
                        }
                    )
                }
                let data = JSON.parse(rtn.stdout);
                if (data.status === 0) {
                    buildResult.push({
                        ...data,
                        param
                    })
                } else {
                    failOrders.push(
                        {
                            param,
                            errMsg: data
                        }
                    )
                }
            }
            return {successOrders: buildResult, failOrders};
        } catch (error) {
            const stackStr = error.stack ? error.stack : JSON.stringify(error);
            console.log(stackStr, "pushJdPayOrder.................error")
            self.execClientNew.execLogs("igirl-channel-pushJdPayOrder-error", queryobj, "igirl-channel-pushJdPayOrder", null, stackStr);
            return system.getResultFail(-200, "操作error");
        }
    }

    async getToken() {
        var reqTokenUrl = this.channelApiUrl + "/auth/accessAuth/getToken";
        var reqParam = {};
        var rtn = await this.execClient.execPost({
            appkey: "201911251551",
            secret: "56006077354d48858026c80c0e10bef6"
        }, reqTokenUrl);
        if (!rtn.stdout) {
            return system.getResult(null, "获取token失败");
        }
        var tokenResult = JSON.parse(rtn.stdout);
        if (tokenResult.status == 0) {
            tokenResult.data.secret = reqParam.secret;
        }
        return tokenResult;
    }

}

module.exports = TmqueryService;
