var childproc = require('child_process');
const util = require('util');
const exec = util.promisify(require('child_process').exec);
const uuidv4 = require('uuid/v4');

class ExecClient {
    constructor() {
        this.cmdPostPattern = "curl --user admines:adminGSBes. -k -H 'Content-type: application/json'  -d '{data}' {url}";
        this.cmdGetPattern = "curl -G -X GET '{url}'";
        this.cmdPushDataPostPattern = "curl -k -H 'Content-type: application/json' -H 'token:{tk}' -H 'request-id:{requestId}' -d '{data}' {url}";
        this.cmdDataPostByTokenUserPinPattern = "curl -k -H 'Content-type: application/json' -H 'token:{tk}' -H 'userpin:{UPIN}' -d '{data}' {url}";

    }

    getUUID() {
        var uuid = uuidv4();
        var u = uuid.replace(/\-/g, "");
        return u;
    }

    async exec(cmd) {
        //await后面表达式返回的promise对象，是then的语法糖，await返回then函数的返回值
        //异常需要try/catch自己捕获或外部catch捕获
        const {stdout, stderr} = await exec(cmd);
        return {stdout, stderr};
    }

    async newExec(cmd, options) {
        //await后面表达式返回的promise对象，是then的语法糖，await返回then函数的返回值
        //异常需要try/catch自己捕获或外部catch捕获
        const {stdout, stderr} = await exec(cmd, options);
        return {stdout, stderr};
    }


    async exec2(cmd) {
        return exec(cmd, {encoding: "base64"});
    }

    FetchPostCmd(subData, url) {
        var data = JSON.stringify(subData);
        var cmd = this.cmdPostPattern.replace(/\{data\}/g,
            data).replace(/\{url\}/g, url);
        console.log(cmd, "cmd......................................");
        return cmd;
    }

    FetchPushDataPostCmd(subData, url, token, requestId) {
        var requestId = requestId || this.getUUID();
        var data = JSON.stringify(subData);
        var cmd = this.cmdPushDataPostPattern.replace(/\{data\}/g,
            data).replace(/\{url\}/g, url).replace(/\{tk\}/g, token).replace(/\{requestId\}/g, requestId);
        console.log(cmd);
        return cmd;
    }

    execDataPostByTokenUserPinCmd(subData, url, token, userPin) {
        var data = JSON.stringify(subData);
        var cmd = this.cmdDataPostByTokenUserPinPattern.replace(/\{data\}/g,
            data).replace(/\{url\}/g, url).replace(/\{tk\}/g, token).replace(/\{UPIN\}/g, userPin);
        console.log(cmd);
        return cmd;
    }

    async execPost(subData, url) {
        let cmd = this.FetchPostCmd(subData, url);
        var result = await this.exec(cmd);
        return result;
    }

    /**
     * 带超时时间的post请求
     * @param {*} params 请求数据-json格式
     * @param {*} url 请求地址
     * @param {*} ContentType 请求头类型，默认application/json
     * @param {*} headData 请求头内容-json格式，如：请求头中传递token,格式：{token:"9098902q849q0434q09439"}
     * @param {*} timeOut 超时时间设置，单位秒
     */
    async execPostTimeOut(params, url, timeOut = 5000) {
        let cmd = this.FetchPostCmd(params, url);
        let options = {
            timeout: timeOut,
            maxBuffer: 1024 * 1024 * 10000
        };
        let result = await this.newExec(cmd, options);
        return result;
    }

    async execPushDataPost(subData, url, token, requestId, timeOut = 5000) {
        let cmd = this.FetchPushDataPostCmd(subData, url, token, requestId);
        let options = {
            timeout: timeOut,
            maxBuffer: 1024 * 1024 * 10000
        };
        var result = await this.newExec(cmd, options);
        return result;
    }

    async execDataPostByTokenUserPin(subData, url, token, userPin) {
        let cmd = this.execDataPostByTokenUserPinCmd(subData, url, token, userPin);
        var result = await this.exec(cmd);
        return result;
    }

    async execPost2(subData, url) {
        let cmd = this.FetchPostCmd(subData, url);
        var result = await this.exec2(cmd);
        return result;
    }

    FetchGetCmd(subData, url) {
        var cmd = this.cmdGetPattern.replace(
            /\{data\}/g, subData).replace(/\{url\}/g, url);
        console.log(cmd);
        return cmd;
    }

    async execGet(subData, url) {
        let cmd = this.FetchGetCmd(subData, url);
        console.log(cmd);
        var result = await this.exec(cmd);
        return result;
    }

    async execGet2(subData, url) {
        let cmd = this.FetchGetCmd(subData, url);
        console.log(cmd);
        var result = await this.exec2(cmd);
        return result;
    }

    async execGetTimeOut(subData, url, timeOut = 5000) {
        //timeOut，单位是毫秒
        let cmd = this.FetchGetCmd(subData, url);
        var options = {
            timeout: timeOut,
        };
        const {stdout, stderr} = await exec(cmd, options);
        return {stdout, stderr};
    }
}

module.exports = ExecClient;
// var x=new RestClient();
// x.execGet("","http://www.163.com").then(function(r){
//   console.log(r.stdout);
//   console.log(r.stderr);
// });
